@@ -1,6 +1,6 @@
 package Enbld::Definition::Ruby;
 
-use 5.012;
+use strict;
 use warnings;
 
 use parent qw/Enbld::Definition/;
@@ -15,7 +15,7 @@ sub initialize {
     $self->{defined}{ArchiveName}    = 'ruby';
     $self->{defined}{WebSite}        = 'https://www.ruby-lang.org';
     $self->{defined}{VersionForm}    = '\d\.\d\.\d-p\d{1,3}';
-    $self->{defined}{Dependencies}   = \&set_Dependencies;
+    $self->{defined}{Dependencies}   = [ 'openssl' ];
     $self->{defined}{DownloadSite}   = 'http://cache.ruby-lang.org/pub/ruby/';
 
     $self->{defined}{AdditionalArgument} = \&set_argument;
@@ -24,10 +24,6 @@ sub initialize {
     return $self;
 }
 
-sub set_Dependencies {
-    return $^O eq 'darwin' ? [ 'openssl' ] : undef;
-}
-
 sub set_sorted_version_list {
     my $attributes = shift;
 
@@ -37,9 +33,7 @@ sub set_sorted_version_list {
 }
 
 sub set_argument {
-    return $^O eq 'darwin' ?
-        "--with-openssl-dir=" . Enbld::Home->library :
-        undef;
+    return "--with-openssl-dir=" . Enbld::Home->library;
 }
 
 1;
