@@ -1,6 +1,6 @@
 package Enbld::HTTP;
 
-use 5.012;
+use strict;
 use warnings;
 
 use File::Spec;
