@@ -1,6 +1,6 @@
 package Enbld::RcFile;
 
-use 5.012;
+use strict;
 use warnings;
 
 use autodie;
